============
parselglossy
============


.. image:: https://img.shields.io/pypi/v/parselglossy.svg
        :target: https://pypi.python.org/pypi/parselglossy

.. image:: https://img.shields.io/travis/dev-cafe/parselglossy.svg
        :target: https://travis-ci.org/dev-cafe/parselglossy

.. image:: https://readthedocs.org/projects/parselglossy/badge/?version=latest
        :target: https://parselglossy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/dev-cafe/parselglossy/shield.svg
     :target: https://pyup.io/repos/github/dev-cafe/parselglossy/
     :alt: Updates



Generic input parsing library, speaking in tongues

.. image:: https://github.com/dev-cafe/parselglossy/raw/master/docs/gfx/parse.jpg
     :alt: Parse all the inputs!

* Free software: MIT license
* Documentation: https://parselglossy.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `elgertam/cookiecutter-pipenv`_ project template, based on `audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`elgertam/cookiecutter-pipenv`: https://github.com/elgertam/cookiecutter-pipenv
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
